.. _PyPI: https://pypi.org/

#############################
  Installation Instructions
#############################

================
  Requirements
================

* Python >= 3.11

==============
  Installing
==============

.. note:: 
  
  It is optional, but *highly* recommended,
  and best practice, to create and use a virtual environment.

To install from PyPI_ using ``pip`` :

.. code:: bash

  python3 -m pip install decimaldate

=================
  Documentation
=================

The latest copy of this documentation should always be available at
https://decimaldate.readthedocs.io/en/latest/#.